@@ -28,6 +28,10 @@ setMethod("addAttrToGeom", signature(x = "SpatialLines", y = "data.frame"),
 		SpatialLinesDataFrame(x, y, match.ID = match.ID, ...)
 )
 
+setAs("SpatialLinesDataFrame", "SpatialMultiPointsDataFrame", 
+	function(from)
+		SpatialMultiPointsDataFrame(as(geometry(from), "SpatialMultiPoints"), from@data)
+)
 setAs("SpatialLinesDataFrame", "data.frame", function(from)
     as.data.frame.SpatialLinesDataFrame(from))
 
@@ -96,7 +100,7 @@ setMethod("split", "SpatialLinesDataFrame", split.data.frame)
 
 print.SpatialLinesDataFrame = function(x, ..., digits = getOption("digits"), 
 		asWKT = .asWKT)
-	print(data.frame(asWKTSpatialLines(x, digits), x@data),...)
+	print(data.frame(asWKTSpatialLines(x, digits), x@data),..., digits = digits)
 
 setMethod("geometry", "SpatialLinesDataFrame",
 	function(obj) as(obj, "SpatialLines"))
