@@ -1,6 +1,9 @@
 SpatialPolygonsDataFrame <- function(Sr, data, match.ID = TRUE) {
 # Barry comment 110610
-        stopifnot(length(Sr@polygons) == nrow(data))
+        if (length(Sr@polygons) != nrow(data))
+          stop(paste("Object length mismatch:\n    ", deparse(substitute(Sr)),
+            "has", length(Sr@polygons), "Polygons objects, but",
+            deparse(substitute(data)), "has", nrow(data), "rows", sep=" "))
 	if (is.character(match.ID)) {
 		row.names(data) = data[, match.ID[1]]
 		match.ID = TRUE
@@ -8,8 +11,7 @@ SpatialPolygonsDataFrame <- function(Sr, data, match.ID = TRUE) {
 	if (match.ID) {
 #		Sr_IDs <- sapply(slot(Sr, "polygons"),
 #                    function(i) slot(i, "ID"))
-                Sr_IDs <- .Call("SpatialPolygons_getIDs_c", Sr,
-                    PACKAGE="sp")
+                Sr_IDs <- .Call(SpatialPolygons_getIDs_c, Sr)
 		data_IDs <- row.names(data)
 		mtch <- match(Sr_IDs, data_IDs)
                 if (!identical(Sr_IDs, data_IDs)) {
@@ -60,7 +62,7 @@ setAs("SpatialPolygonsDataFrame", "data.frame", function(from)
     as.data.frame.SpatialPolygonsDataFrame(from))
 
 row.names.SpatialPolygonsDataFrame <- function(x) {
-    .Call("SpatialPolygons_getIDs_c", x, PACKAGE="sp")
+    .Call(SpatialPolygons_getIDs_c, x)
 }
 
 "row.names<-.SpatialPolygonsDataFrame" <- function(x, value) {
@@ -89,28 +91,27 @@ setMethod("[", "SpatialPolygonsDataFrame", function(x, i, j, ... , drop = TRUE)
 		i = !is.na(over(x, geometry(i)))
     if (any(is.na(i)))
 		stop("NAs not permitted in row index")
-    #SpatialPolygonsDataFrame(as(x, "SpatialPolygons")[i, , drop = FALSE],
-    #    data = x@data[i, j, drop = FALSE], match.ID = FALSE)
-        y <- new("SpatialPolygonsDataFrame")
-	y@proj4string <- x@proj4string
-	y@data = x@data[i, j, ..., drop = FALSE]
 	if (is.logical(i)) {
 		if (length(i) == 1 && i)
 			i = 1:length(x@polygons)
 		else
 			i <- which(i)
-	} else if (is.character(i)) {
-                i <- match(i, row.names(x))
-        }
+	} 
+	if (is.character(i))
+		i <- match(i, row.names(x))
+    #SpatialPolygonsDataFrame(as(x, "SpatialPolygons")[i, , drop = FALSE],
+    #    data = x@data[i, j, drop = FALSE], match.ID = FALSE)
+	y <- new("SpatialPolygonsDataFrame")
+	y@proj4string <- x@proj4string
+	y@data = x@data[i, j, ..., drop = FALSE]
 
 	y@polygons = x@polygons[i]
 #	x@bbox <- .bboxCalcR(x@polygons)
-        y@bbox <- .Call("bboxCalcR_c", y@polygons, PACKAGE="sp")
+        y@bbox <- .Call(bboxCalcR_c, y@polygons)
         if (is.numeric(i) && i < 0) {
 #             area <- sapply(x@polygons, function(y) y@area)
 #             x@plotOrder <- as.integer(order(area, decreasing=TRUE))
-              y@plotOrder <- .Call("SpatialPolygons_plotOrder_c",
-                  y@polygons, PACKAGE="sp")
+              y@plotOrder <- .Call(SpatialPolygons_plotOrder_c, y@polygons)
         } else {
 	    y@plotOrder = order(match(i, x@plotOrder))
         }
